summaryrefslogtreecommitdiff
path: root/basctl/source/basicide/baside2.hxx
diff options
context:
space:
mode:
authorMikhail Voytenko <mav@openoffice.org>2011-01-14 11:16:25 +0100
committerMikhail Voytenko <mav@openoffice.org>2011-01-14 11:16:25 +0100
commit1e03f9a5bfa9951343e890aaa8310e363f1da796 (patch)
treee8caf89911851890fc9e8a3a491c9dce8b26a4a3 /basctl/source/basicide/baside2.hxx
parent41295f88e2b7dab7911fb31a100249e00608039d (diff)
removetooltypes01: #i112600# remove tooltypes from basctl
Diffstat (limited to 'basctl/source/basicide/baside2.hxx')
-rw-r--r--basctl/source/basicide/baside2.hxx114
1 files changed, 57 insertions, 57 deletions
diff --git a/basctl/source/basicide/baside2.hxx b/basctl/source/basicide/baside2.hxx
index b78eaf8dd..9c2933148 100644
--- a/basctl/source/basicide/baside2.hxx
+++ b/basctl/source/basicide/baside2.hxx
@@ -69,24 +69,24 @@ void setTextEngineText( ExtTextEngine* pEngine, const ::rtl::OUString aStr );
class ProgressInfo : public SfxProgress
{
private:
- ULONG nCurState;
+ sal_uLong nCurState;
public:
- inline ProgressInfo( SfxObjectShell* pObjSh, const String& rText, ULONG nRange );
+ inline ProgressInfo( SfxObjectShell* pObjSh, const String& rText, sal_uLong nRange );
-// inline void StartProgress( const String& rName, ULONG nStates );
+// inline void StartProgress( const String& rName, sal_uLong nStates );
// inline void EndProgress();
inline void StepProgress();
};
-inline ProgressInfo::ProgressInfo( SfxObjectShell* pObjSh, const String& rText, ULONG nRange )
+inline ProgressInfo::ProgressInfo( SfxObjectShell* pObjSh, const String& rText, sal_uLong nRange )
: SfxProgress( pObjSh, rText, nRange )
{
nCurState = 0;
}
// inline void ProgressInfo::StartProgress( const String& rName, ULONG nStates )
// {
// nCurState = 0;
// if ( pStbMgr )
@@ -131,16 +131,16 @@ private:
using Window::Notify;
virtual void Notify( SfxBroadcaster& rBC, const SfxHint& rHint );
- void ImpDoHighlight( ULONG nLineOff );
+ void ImpDoHighlight( sal_uLong nLineOff );
void ImplSetFont();
- BOOL bHighlightning;
- BOOL bDoSyntaxHighlight;
- BOOL bDelayHighlight;
+ sal_Bool bHighlightning;
+ sal_Bool bDoSyntaxHighlight;
+ sal_Bool bDelayHighlight;
virtual
::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindowPeer >
- GetComponentInterface(BOOL bCreate = TRUE);
+ GetComponentInterface(sal_Bool bCreate = sal_True);
protected:
virtual void Paint( const Rectangle& );
@@ -154,9 +154,9 @@ protected:
virtual void RequestHelp( const HelpEvent& rHEvt );
virtual void ConfigurationChanged( utl::ConfigurationBroadcaster*, sal_uInt32 );
- void DoSyntaxHighlight( ULONG nPara );
+ void DoSyntaxHighlight( sal_uLong nPara );
String GetWordAtCursor();
- BOOL ImpCanModify();
+ sal_Bool ImpCanModify();
public:
EditorWindow( Window* pParent );
@@ -166,11 +166,11 @@ public:
ExtTextView* GetEditView() const { return pEditView; }
ProgressInfo* GetProgress() const { return pProgress; }
- void CreateProgress( const String& rText, ULONG nRange );
+ void CreateProgress( const String& rText, sal_uLong nRange );
void DestroyProgress();
- void ParagraphInsertedDeleted( ULONG nNewPara, BOOL bInserted );
- void DoDelayedSyntaxHighlight( ULONG nPara );
+ void ParagraphInsertedDeleted( sal_uLong nNewPara, sal_Bool bInserted );
+ void DoDelayedSyntaxHighlight( sal_uLong nPara );
void CreateEditEngine();
void SetScrollBarRanges();
@@ -179,9 +179,9 @@ public:
{ pModulWindow = pWin; }
void ForceSyntaxTimeout();
- BOOL SetSourceInBasic( BOOL bQuiet = TRUE );
+ sal_Bool SetSourceInBasic( sal_Bool bQuiet = sal_True );
- BOOL CanModify() { return ImpCanModify(); }
+ sal_Bool CanModify() { return ImpCanModify(); }
};
@@ -189,10 +189,10 @@ class BreakPointWindow : public Window
{
private:
long nCurYOffset;
- USHORT nMarkerPos;
+ sal_uInt16 nMarkerPos;
BreakPointList aBreakPointList;
ModulWindow* pModulWindow;
- BOOL bErrorMarker;
+ sal_Bool bErrorMarker;
bool m_bHighContrastMode;
virtual void DataChanged(DataChangedEvent const & rDCEvt);
@@ -203,11 +203,11 @@ protected:
virtual void Paint( const Rectangle& );
virtual void Resize();
BreakPoint* FindBreakPoint( const Point& rMousePos );
- void ShowMarker( BOOL bShow );
+ void ShowMarker( sal_Bool bShow );
virtual void MouseButtonDown( const MouseEvent& rMEvt );
virtual void Command( const CommandEvent& rCEvt );
- BOOL SyncYOffset();
+ sal_Bool SyncYOffset();
public:
BreakPointWindow( Window* pParent );
@@ -216,7 +216,7 @@ public:
void SetModulWindow( ModulWindow* pWin )
{ pModulWindow = pWin; }
- void SetMarkerPos( USHORT nLine, BOOL bErrorMarker = FALSE );
+ void SetMarkerPos( sal_uInt16 nLine, sal_Bool bErrorMarker = sal_False );
void DoScroll( long nHorzScroll, long nVertScroll );
long& GetCurYOffset() { return nCurYOffset; }
@@ -229,21 +229,21 @@ class WatchTreeListBox : public SvHeaderTabListBox
String aEditingRes;
protected:
- virtual BOOL EditingEntry( SvLBoxEntry* pEntry, Selection& rSel );
- virtual BOOL EditedEntry( SvLBoxEntry* pEntry, const String& rNewText );
+ virtual sal_Bool EditingEntry( SvLBoxEntry* pEntry, Selection& rSel );
+ virtual sal_Bool EditedEntry( SvLBoxEntry* pEntry, const String& rNewText );
- BOOL ImplBasicEntryEdited( SvLBoxEntry* pEntry, const String& rResult );
+ sal_Bool ImplBasicEntryEdited( SvLBoxEntry* pEntry, const String& rResult );
SbxBase* ImplGetSBXForEntry( SvLBoxEntry* pEntry, bool& rbArrayElement );
// virtual DragDropMode NotifyBeginDrag( SvLBoxEntry* );
// virtual BOOL NotifyQueryDrop( SvLBoxEntry* );
// virtual BOOL NotifyMoving( SvLBoxEntry* pTarget, SvLBoxEntry* pEntry,
// SvLBoxEntry*& rpNewParent, ULONG& rNewChildPos );
// virtual BOOL NotifyCopying( SvLBoxEntry* pTarget, SvLBoxEntry* pEntry,
// SvLBoxEntry*& rpNewParent, ULONG& rNewChildPos );
// BOOL NotifyCopyingMoving( SvLBoxEntry* pTarget, SvLBoxEntry* pEntry,
// SvLBoxEntry*& rpNewParent, ULONG& rNewChildPos, BOOL bMove );
public:
WatchTreeListBox( Window* pParent, WinBits nWinBits );
@@ -282,7 +282,7 @@ public:
~WatchWindow();
void AddWatch( const String& rVName );
- BOOL RemoveSelectedWatch();
+ sal_Bool RemoveSelectedWatch();
void UpdateWatches( bool bBasicStopped = false );
WatchTreeListBox& GetWatchTreeListBox() { return aTreeListBox; }
@@ -351,7 +351,7 @@ private:
long BasicBreakHdl( StarBASIC* pBasic );
void CheckCompileBasic();
- BOOL BasicExecute();
+ sal_Bool BasicExecute();
void GoOnTop();
void AssertValidEditEngine();
@@ -378,7 +378,7 @@ public:
virtual void GetState( SfxItemSet& );
virtual void StoreData();
virtual void UpdateData();
- virtual BOOL CanClose();
+ virtual sal_Bool CanClose();
// virtual void PrintData( Printer* pPrinter );
// return number of pages to be printed
virtual sal_Int32 countPages( Printer* pPrinter );
@@ -386,9 +386,9 @@ public:
virtual void printPage( sal_Int32 nPage, Printer* pPrinter );
virtual String GetTitle();
virtual BasicEntryDescriptor CreateEntryDescriptor();
- virtual BOOL AllowUndo();
- virtual void SetReadOnly( BOOL bReadOnly );
- virtual BOOL IsReadOnly();
+ virtual sal_Bool AllowUndo();
+ virtual void SetReadOnly( sal_Bool bReadOnly );
+ virtual sal_Bool IsReadOnly();
StarBASIC* GetBasic() { XModule(); return xBasic; }
@@ -396,39 +396,39 @@ public:
void SetSbModule( SbModule* pModule ) { xModule = pModule; }
String GetSbModuleName();
- BOOL CompileBasic();
- BOOL BasicRun();
- BOOL BasicStepOver();
- BOOL BasicStepInto();
- BOOL BasicStepOut();
+ sal_Bool CompileBasic();
+ sal_Bool BasicRun();
+ sal_Bool BasicStepOver();
+ sal_Bool BasicStepInto();
+ sal_Bool BasicStepOut();
void BasicStop();
- BOOL BasicToggleBreakPoint();
+ sal_Bool BasicToggleBreakPoint();
void BasicToggleBreakPointEnabled();
void ManageBreakPoints();
void UpdateBreakPoint( const BreakPoint& rBrk );
void BasicAddWatch();
void BasicRemoveWatch();
- BOOL LoadBasic();
- BOOL SaveBasicSource();
- BOOL ImportDialog();
+ sal_Bool LoadBasic();
+ sal_Bool SaveBasicSource();
+ sal_Bool ImportDialog();
void EditMacro( const String& rMacroName );
// void InsertFromObjectCatalog( ObjectCatalog* pObjDlg );
- BOOL ToggleBreakPoint( ULONG nLine );
+ sal_Bool ToggleBreakPoint( sal_uLong nLine );
BasicStatus& GetBasicStatus() { return aStatus; }
- virtual BOOL IsModified();
- virtual BOOL IsPasteAllowed();
+ virtual sal_Bool IsModified();
+ virtual sal_Bool IsPasteAllowed();
void FrameWindowMoved();
- void ShowCursor( BOOL bOn );
+ void ShowCursor( sal_Bool bOn );
- virtual USHORT GetSearchOptions();
- USHORT StartSearchAndReplace( const SvxSearchItem& rSearchItem, BOOL bFromStart = FALSE );
+ virtual sal_uInt16 GetSearchOptions();
+ sal_uInt16 StartSearchAndReplace( const SvxSearchItem& rSearchItem, sal_Bool bFromStart = sal_False );
virtual Window* GetLayoutWindow();
@@ -459,8 +459,8 @@ private:
WatchWindow aWatchWindow;
StackWindow aStackWindow;
- BOOL bVSplitted;
- BOOL bHSplitted;
+ sal_Bool bVSplitted;
+ sal_Bool bHSplitted;
ModulWindow * m_pModulWindow;
@@ -489,7 +489,7 @@ public:
~ModulWindowLayout();
void DockaWindow( DockingWindow* pDockingWin );
- BOOL IsToBeDocked( DockingWindow* pDockingWin, const Point& rPos, Rectangle& rRect );
+ sal_Bool IsToBeDocked( DockingWindow* pDockingWin, const Point& rPos, Rectangle& rRect );
void SetModulWindow( ModulWindow* pModWin );
ModulWindow* GetModulWindow() const { return m_pModulWindow; }
@@ -497,7 +497,7 @@ public:
WatchWindow& GetWatchWindow() { return aWatchWindow; }
StackWindow& GetStackWindow() { return aStackWindow; }
- Image getImage(USHORT nId, bool bHighContrastMode) const;
+ Image getImage(sal_uInt16 nId, bool bHighContrastMode) const;
inline Color const & getSyntaxColor(TokenTypes eType) const
{ return m_aSyntaxColors[eType]; }
@@ -69,24 +69,24 @@ void setTextEngineText( ExtTextEngine* pEngine, const ::rtl::OUString aStr );
nCurState = 0;
}
-// inline void ProgressInfo::StartProgress( const String& rName, ULONG nStates )
+// inline void ProgressInfo::StartProgress( const String& rName, sal_uLong nStates )
// {
// nCurState = 0;
@@ -229,21 +229,21 @@ class WatchTreeListBox : public SvHeaderTabListBox
SbxBase* ImplGetSBXForEntry( SvLBoxEntry* pEntry, bool& rbArrayElement );
// virtual DragDropMode NotifyBeginDrag( SvLBoxEntry* );
-// virtual BOOL NotifyQueryDrop( SvLBoxEntry* );
+// virtual sal_Bool NotifyQueryDrop( SvLBoxEntry* );
-// virtual BOOL NotifyMoving( SvLBoxEntry* pTarget, SvLBoxEntry* pEntry,
-// SvLBoxEntry*& rpNewParent, ULONG& rNewChildPos );
-// virtual BOOL NotifyCopying( SvLBoxEntry* pTarget, SvLBoxEntry* pEntry,
-// SvLBoxEntry*& rpNewParent, ULONG& rNewChildPos );
-// BOOL NotifyCopyingMoving( SvLBoxEntry* pTarget, SvLBoxEntry* pEntry,
-// SvLBoxEntry*& rpNewParent, ULONG& rNewChildPos, BOOL bMove );
+// virtual sal_Bool NotifyMoving( SvLBoxEntry* pTarget, SvLBoxEntry* pEntry,
+// SvLBoxEntry*& rpNewParent, sal_uLong& rNewChildPos );
+// virtual sal_Bool NotifyCopying( SvLBoxEntry* pTarget, SvLBoxEntry* pEntry,
+// SvLBoxEntry*& rpNewParent, sal_uLong& rNewChildPos );
+// sal_Bool NotifyCopyingMoving( SvLBoxEntry* pTarget, SvLBoxEntry* pEntry,
+// SvLBoxEntry*& rpNewParent, sal_uLong& rNewChildPos, sal_Bool bMove );
public:
WatchTreeListBox( Window* pParent, WinBits nWinBits );